@@ -13,6 +13,7 @@
 #ifndef ZYPP_MEDIA_MEDIAHANDLERL_H
 #define ZYPP_MEDIA_MEDIAHANDLERL_H
 
+#include <any>
 #include <iosfwd>
 #include <string>
 #include <list>
@@ -21,12 +22,11 @@
 #include <zypp/PathInfo.h>
 #include <zypp/base/PtrTypes.h>
 
-#include <zypp/Url.h>
-
 #include <zypp/media/MediaSource.h>
 #include <zypp-media/MediaException>
-#include <zypp/APIConfig.h>
+#include <zypp-core/Globals.h>
 #include <zypp-core/OnMediaLocation>
+#include <zypp-core/MirroredOrigin.h>
 
 #undef ZYPP_BASE_LOGGER_LOGGROUP
 #define ZYPP_BASE_LOGGER_LOGGROUP "zypp::media"
@@ -36,7 +36,6 @@ namespace zypp {
 
     class MediaManager;
 
-
 ///////////////////////////////////////////////////////////////////
 //
 //	CLASS NAME : MediaHandler
@@ -48,13 +47,12 @@ namespace zypp {
  * logging. For the real action they call virtual methods overloaded by the
  * concrete handler.
  **/
-class ZYPP_TESTS MediaHandler {
+class MediaHandler {
     friend std::ostream & operator<<( std::ostream & str, const MediaHandler & obj );
 
     public:
         using Ptr = shared_ptr<MediaHandler>;
         using constPtr = shared_ptr<const MediaHandler>;
-
         static bool setAttachPrefix(const Pathname &attach_prefix);
 
         static std::string getRealPath(const std::string &path);
@@ -107,10 +105,11 @@ class ZYPP_TESTS MediaHandler {
         mutable time_t  _attach_mtime;
 
     protected:
+
         /**
-         * Url to handle
-         **/
-        const Url        _url;
+         * Contains the authority URL and mirrors.
+         */
+        MirroredOrigin _origin;
 
         /**
          * Access Id of media handler we depend on.
@@ -466,7 +465,7 @@ class ZYPP_TESTS MediaHandler {
          * On any error, the attach_point is set to an empty Pathname,
          * which should lead to E_bad_attachpoint.
          **/
-        MediaHandler ( Url        url_r,
+        MediaHandler ( MirroredOrigin origin_r,
                        const Pathname & attach_point_r,
                        Pathname  urlpath_below_attachpoint_r,
                        const bool       does_download_r );
@@ -495,12 +494,17 @@ class ZYPP_TESTS MediaHandler {
         /**
          * Protocol hint for MediaAccess.
          **/
-        std::string protocol() const { return _url.getScheme(); }
+        std::string protocol() const { return _origin.scheme(); }
 
         /**
-         * Url used.
+         * Primary Url used.
          **/
-        Url url() const { return _url; }
+        Url url() const { return _origin.authority().url(); }
+
+        /**
+         * Primary OriginEndpoint used.
+         **/
+        OriginEndpoint originEndpoint() const { return _origin.authority(); }
 
         /**
          * Use concrete handler to attach the media.
